//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[dora](dora.md)

# dora

[common]\
val [dora](dora.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

#### Parameters

common

| | |
|---|---|
| dora | 宝牌数目 |
